# research-utils
[![Build](https://github.com/r08521610/research-utils/actions/workflows/package-build.yml/badge.svg)](https://github.com/r08521610/research-utils/actions/workflows/package-build.yml)
[![Publish Package](https://github.com/r08521610/research-utils/actions/workflows/package-publish.yml/badge.svg?branch=main)](https://github.com/r08521610/research-utils/actions/workflows/package-publish.yml)
[![PyPI version](https://badge.fury.io/py/research-utils.svg)](https://badge.fury.io/py/research-utils)
